@@ -1,7 +1,8 @@
-import click
-import grpc
+import logging
 
-from grebble_flow.protobuf import manager
+import click
+
+from grebble_flow.transport import manager
 
 
 @click.group()
@@ -29,5 +30,6 @@ def cli():
     required=False,
     show_default=True,
 )
-def runprocessor(port=5000, debug=False, socket=False):
+def run(port=5000, debug=False, socket=False):
+    print("Starting processors server")
     manager.start_server(port)
