@@ -7,6 +7,12 @@ class FlowManager:
     def __init__(self):
         self.processor_classes = find_all_processors()
 
+    def init_processor(self, processor):
+        return processor()
+
+    def get_all_processor_classes(self):
+        return self.processor_classes
+
     def find_processor_instance_by_name(self, flow_name):
         result = [x for x in self.processor_classes if x.name == flow_name]
         if not result:
